# Do a systemd-based build from F-15; otherwise, a sysvinit-based build
%global use_systemd %([ "(" 0%{?fedora} -gt 14 ")" -o "(" 0%{?rhel} -gt 6 ")" ] && echo 1 || echo 0)
 
# With systemd, the run directory is /run; otherwise it's /var/run
%if %{use_systemd}
%global rundir /run
%else
%global rundir %{_localstatedir}/run
%endif

# systemd-units merged into systemd at Fedora 17
%if (0%{?fedora} && 0%{?fedora} <= 16)
%global systemd_units systemd-units
%else
%global systemd_units systemd
%endif

# Milter header files package name
%if 0%{?fedora} > 25 || 0%{?rhel} > 7
%global milter_devel_package sendmail-milter-devel
%else
%global milter_devel_package sendmail-devel
%endif

Summary:	Mail filter for sender address validation
Name:		smf-sav
Version:	2.1
Release:	4%{?dist}
License:	GPLv2+
URL:		http://smf-sav.anw.at/
Source0:	http://smf-sav.anw.at/smf-sav-reloaded-%{version}.tar.gz
Source1:	smf-sav.sysv
Source2:	smf-sav.service
Source3:	smfs.conf
Source4:	README.rpm
Patch0:		smf-sav-2.1-bubble.patch
Patch1:		smf-sav-1.4.0-nostrip.patch
Patch4:		smf-sav-2.1-config.patch
Patch5:		smf-sav-2.1-rundir.patch
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	%milter_devel_package
Requires(pre):	shadow-utils
%if %{use_systemd}
BuildRequires:	%{systemd_units}
Requires(post):	%{systemd_units}
Requires(preun): %{systemd_units}
Requires(postun): %{systemd_units}
%else
Requires(post):	chkconfig
Requires(preun): chkconfig, initscripts
Requires(postun): initscripts
%endif

%description
A lightweight, fast and reliable milter that implements a real-time sender
address verification technology. This technology can stop some kinds of spam
with spoofed sender's email addresses. Also it implements a real-time
recipient address verification technology. It can be useful if your machine
is a backup MX for the recipients' domains or if your machine forwards all
email messages as a relay host for your domains to another internal or
external email servers. 

%prep
%setup -q -n smf-sav-reloaded-%{version}

# Copy in additional sources
cp -a %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} .

# Miscellaneous third-party enhancements
%patch0

# Don't strip the binary so we get usable debuginfo
%patch1 -p1

# Clean up config file for packaging
%patch4

# Use /run rather than /var/run with systemd
%if %{use_systemd}
%patch5
%endif

%build
make %{?_smp_mflags} \
	DATADIR="%{rundir}/smfs" \
	CFLAGS="%{optflags} -pthread -D_GNU_SOURCE" \
	LDFLAGS="-lmilter -lpthread -lresolv"

%install
install -d -m 711 %{buildroot}%{rundir}/smfs
install -Dp -m 755 smf-sav %{buildroot}%{_sbindir}/smf-sav
install -Dp -m 644 smf-sav.conf %{buildroot}%{_sysconfdir}/mail/smfs/smf-sav.conf
%if %{use_systemd}
# Install systemd unit file and tmpfiles.d configuration for /run/smfs
install -Dp -m 644 smf-sav.service %{buildroot}%{_unitdir}/smf-sav.service
install -Dp -m 644 smfs.conf %{buildroot}%{_prefix}/lib/tmpfiles.d/smfs.conf
%else
# Install SysV initscript
install -Dp -m 755 smf-sav.sysv %{buildroot}%{_initddir}/smf-sav
%endif

# Create dummy socket for %%ghost-ing
: > %{buildroot}%{rundir}/smfs/smf-sav.sock

%pre
getent group smfs >/dev/null || groupadd -r smfs
getent passwd smfs >/dev/null || \
	useradd -r -g smfs -d %{_localstatedir}/lib/smfs \
		-s /sbin/nologin -c "Smart Sendmail Filters" smfs
exit 0

%post
if [ $1 -eq 1 ]; then 
	# Initial installation 
%if %{use_systemd}
	systemctl daemon-reload &>/dev/null || :
%else
	chkconfig --add smf-sav || :
%endif
fi

%preun
if [ $1 -eq 0 ]; then
	# Package removal, not upgrade
%if %{use_systemd}
	systemctl --no-reload disable smf-sav.service &>/dev/null || :
	systemctl stop smf-sav.service &>/dev/null || :
%else
	%{_initddir}/smf-sav stop &>/dev/null || :
	chkconfig --del smf-sav || :
%endif
fi

%postun
%if %{use_systemd}
systemctl daemon-reload &>/dev/null || :
%endif
if [ $1 -ge 1 ]; then
	# Package upgrade, not uninstall
%if %{use_systemd}
	systemctl try-restart smf-sav.service &>/dev/null || :
%else
	%{_initddir}/smf-sav condrestart &>/dev/null || :
%endif
fi

%files
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%doc ChangeLog readme README.rpm
%{_sbindir}/smf-sav
%dir %{_sysconfdir}/mail/smfs/
%config(noreplace) %{_sysconfdir}/mail/smfs/smf-sav.conf
%attr(0700,smfs,smfs) %dir %{rundir}/smfs/
%ghost %{rundir}/smfs/smf-sav.sock
%if %{use_systemd}
%{_prefix}/lib/tmpfiles.d/smfs.conf
%{_unitdir}/smf-sav.service
%else
%{_initddir}/smf-sav
%endif

%changelog
* Sun Mar 24 2019 Paul Howarth <paul@city-fan.org> - 2.1-4
- Fix permissions of /run/smfs so that dac_read_search capability is not
  needed during milter start-up

* Tue Mar 13 2018 Paul Howarth <paul@city-fan.org> - 2.1-3
- systemd-units merged into systemd at Fedora 17
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - %%{_initddir} macro always available

* Fri Aug  5 2016 Paul Howarth <paul@city-fan.org> - 2.1-2
- sendmail-devel renamed to sendmail-milter-devel from Fedora 26
- Use %%license where possible

* Fri Jan 15 2016 Paul Howarth <paul@city-fan.org> - 2.1-1
- Switch upstream to smf-sav-reloaded
- Port "bubble" patch (adds PID file, ability to disable RAV, ability to
  distinguish between local and SMTP mailers) to new version
- Update rundir patch

* Sun Jul 28 2013 Paul Howarth <paul@city-fan.org> - 1.4.0-5
- Systemd detection was broken in F-19 so hardcode it instead

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> - 1.4.0-4
- Move tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib
- Delay start-up until after network

* Thu Sep 29 2011 Paul Howarth <paul@city-fan.org> - 1.4.0-3
- Use presence of /run/lock to determine if init is systemd

* Tue Jul 12 2011 Paul Howarth <paul@city-fan.org> - 1.4.0-2
- Switch to systemd configuration where appropriate
- Nobody else likes macros for commands

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> - 1.4.0-1
- Initial RPM version
